@@ -11,18 +11,18 @@ from watson.framework import events
 debug = {
     'enabled': False,
     'panels': {
-        'watson.framework.debug.panels.request.Panel': {
+        'watson.framework.debug.panels.Request': {
             'enabled': True
         },
-        'watson.framework.debug.panels.application.Panel': {
+        'watson.framework.debug.panels.Application': {
             'enabled': True
         },
-        'watson.framework.debug.panels.profile.Panel': {
+        'watson.framework.debug.panels.Profile': {
             'enabled': True,
             'max_results': 20,
             'sort': 'time',
         },
-        'watson.framework.debug.panels.framework.Panel': {
+        'watson.framework.debug.panels.Framework': {
             'enabled': True
         },
     }
@@ -55,7 +55,7 @@ dependencies = {
             'item': 'watson.framework.views.renderers.jinja2.Renderer',
             'init': [
                 lambda container: container.get('application.config')[
-                    'views']['renderers']['default'].get('config', {}),
+                    'views']['renderers']['jinja2'].get('config', {}),
                 lambda container: container.get('application')
             ]
         },
@@ -87,8 +87,9 @@ dependencies = {
 # View settings
 views = {
     'default_format': 'html',
+    'default_renderer': 'jinja2',
     'renderers': {
-        'default': {
+        'jinja2': {
             'name': 'jinja2_renderer',
             'config': {
                 'extension': 'html',
